pub async fn verify_email_with_resolver<'a>(
email: &'a ParsedEmail<'a>,
resolver: &dyn Resolver,
) -> Result<Vec<AuthenticationResult>, DKIMError>Expand description
Run the DKIM verification on the email providing an existing resolver
pub async fn verify_email_with_resolver<'a>(
email: &'a ParsedEmail<'a>,
resolver: &dyn Resolver,
) -> Result<Vec<AuthenticationResult>, DKIMError>Run the DKIM verification on the email providing an existing resolver